@@ -7,9 +7,11 @@ from .errors.quandl_error import *
 from .model.database import Database
 from .model.dataset import Dataset
 from .model.datatable import Datatable
+from .model.point_in_time import PointInTime
 from .model.data import Data
 from .model.merged_dataset import MergedDataset
 from .get import get
 from .bulkdownload import bulkdownload
 from .export_table import export_table
-from .get_table import get_table
\ No newline at end of file
+from .get_table import get_table
+from .get_point_in_time import get_point_in_time
\ No newline at end of file
